@@ -21,7 +21,7 @@ HOTSPOT_JTREG_PATH=test/hotspot/jtreg
 HOTSPOT_JTREG_NATIVE_PATH=${jdk_path}/testsuite/hotspot/jtreg/native
 
 problem_list=${AUTOPKGTEST_TMP}/problems.txt
-debian/tests/write-problems ${problem_list} ${HOTSPOT_JTREG_PATH}/ProblemList.txt hotspot
+debian/tests/write-problems.sh ${problem_list} ${HOTSPOT_JTREG_PATH}/ProblemList.txt hotspot
 
 ARGS="$*"
 JT_DEFAULT_ARGS="-exclude:${problem_list} -k:!stress :tier1"
